﻿using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using TddForWpfApplication.Services;

namespace TddForWpfApplication.Models
{
    public class LoginViewModel : ViewModelBase
    {
        #region ctor

        private readonly ILoginService _loginService;
        private readonly INavigationService _navigationService;

        public LoginViewModel(ILoginService loginService, INavigationService navigationService)
        {
            _loginService = loginService;
            _navigationService = navigationService;
        }

        #endregion

        #region Properties

        private string _name;
        public string Name
        {
            get { return _name; }
            set
            {
                _name = value;
                RaisePropertyChanged(() => Name);
                ErrorMessage = string.Empty;
            }
        }

        private string _password;
        public string Password
        {
            get { return _password; }
            set
            {
                _password = value;
                RaisePropertyChanged(() => Password);
                ErrorMessage = string.Empty;
            }
        }

        private string _errorMessage;
        public string ErrorMessage
        {
            get { return _errorMessage; }
            set { _errorMessage = value; RaisePropertyChanged(() => ErrorMessage); }
        }

        #endregion

        #region Commands

        private ICommand _loginCommand;
        public ICommand LoginCommand
        {
            get { return _loginCommand ?? (_loginCommand = new RelayCommand(Login)); }
        }

        private void Login()
        {
            var login = _loginService.Login(Name, Password);
            if (login.IsSuccess)
                _navigationService.NavigateTo(NavigationRegion.StartPage);
            else
                ErrorMessage = login.Message;
        }

        #endregion
    }
}
