﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Controls;
using TddForWpfApplication.Models;
using TddForWpfApplication.Views;

namespace TddForWpfApplication.Services
{
    public enum NavigationRegion
    {
        Login,
        StartPage
    }

    public interface INavigationService
    {
        void NavigateTo(NavigationRegion region);
    }

    public class NavigationService : INavigationService
    {
        private readonly MainWindow _window;

        private readonly ILoginService _loginService;
        private readonly IDataService _dataService;

        public NavigationService(MainWindow window)
        {
            _window = window;
            _loginService = new LoginService();
            _dataService = new DataService();
        }

        public void NavigateTo(NavigationRegion region)
        {
            _window.ContentArea.Content = CreateArea(region);
        }

        private UserControl CreateArea(NavigationRegion region)
        {
            switch (region)
            {
                case NavigationRegion.StartPage:
                    return new MainView { DataContext = new MainViewModel(_dataService, this) };
                default:
                    return new LoginView { DataContext = new LoginViewModel(_loginService, this) };
            }
        }
    }
}
